#[non_exhaustive]
pub enum Generation { V1(GenerationV1), }
An enum of all available bootspec versions.

This enum is nonexhaustive, because there may be future versions added at any point, and tools should explicitly handle them (e.g. by noting they’re currently unsupported).

Warnings

If you attempt to deserialize using this struct, you will not get any information about user-provided extensions. For that, you must deserialize with crate::BootJson.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.

Implementations

source

impl Generation

source

pub fn version(&self) -> u64

The version of the bootspec document.